aboutsummaryrefslogtreecommitdiff
path: root/gas/config
diff options
context:
space:
mode:
authorMichael Tiemann <tiemann@cygnus>1994-11-25 00:01:26 +0000
committerMichael Tiemann <tiemann@cygnus>1994-11-25 00:01:26 +0000
commit03c4ce2fcc3582e65cfe2ec336769074a80f3146 (patch)
tree9b562805138500c7ec159ab177f2d90c3ba0425d /gas/config
parent5fa60968605904d23a6ce37901c9710295baf0b0 (diff)
downloadgdb-03c4ce2fcc3582e65cfe2ec336769074a80f3146.zip
gdb-03c4ce2fcc3582e65cfe2ec336769074a80f3146.tar.gz
gdb-03c4ce2fcc3582e65cfe2ec336769074a80f3146.tar.bz2
Rename r16 files to rce, and fix some more .Sanitize typos.
Diffstat (limited to 'gas/config')
-rw-r--r--gas/config/tc-rce.c (renamed from gas/config/tc-r16.c)12
-rw-r--r--gas/config/tc-rce.h (renamed from gas/config/tc-r16.h)8
2 files changed, 10 insertions, 10 deletions
diff --git a/gas/config/tc-r16.h b/gas/config/tc-rce.h
index 7e82378..98f779d 100644
--- a/gas/config/tc-r16.h
+++ b/gas/config/tc-rce.h
@@ -1,4 +1,4 @@
-/* This file is tc-r16.h
+/* This file is tc-rce.h
Copyright (C) 1993 Free Software Foundation, Inc.
@@ -23,15 +23,15 @@
#ifdef BFD_ASSEMBLER
-#define TARGET_ARCH bfd_arch_r16
+#define TARGET_ARCH bfd_arch_rce
#define TARGET_BYTES_BIG_ENDIAN 1
#ifdef OBJ_AOUT
-#define TARGET_FORMAT "a.out-r16"
+#define TARGET_FORMAT "a.out-rce"
#endif
#else /* ! BFD_ASSEMBLER */
-#define BFD_ARCH bfd_arch_r16
+#define BFD_ARCH bfd_arch_rce
#define NO_RELOC 0
#define RELOC_32 1234
diff --git a/gas/config/tc-r16.c b/gas/config/tc-rce.c
index 153274e..62698aa 100644
--- a/gas/config/tc-r16.c
+++ b/gas/config/tc-rce.c
@@ -1,4 +1,4 @@
/* tc-r16.c -- Assemble code for the Experimental R16
Copyright (C) 1993 Free Software Foundation.
@@ -28,7 +28,7 @@
#include "bfd.h"
#include "subsegs.h"
#define DEFINE_TABLE
-#include "../opcodes/r16-opc.h"
+#include "../opcodes/rce-opc.h"
#include <ctype.h>
#if 1 /**** TEMP ****/
@@ -116,13 +116,13 @@ static struct hash_control *opcode_hash_control; /* Opcode mnemonics */
void
md_begin ()
{
- r16_opcode_info *opcode;
+ rce_opcode_info *opcode;
char *prev_name = "";
opcode_hash_control = hash_new ();
/* Insert unique names into hash table */
- for (opcode = r16_table; opcode->name; opcode++)
+ for (opcode = rce_table; opcode->name; opcode++)
{
if (strcmp (prev_name, opcode->name))
{
@@ -272,7 +272,7 @@ char *str;
{
char *op_start;
char *op_end;
- r16_opcode_info *opcode;
+ rce_opcode_info *opcode;
char *output;
int nlen = 0;
unsigned short inst;
@@ -298,7 +298,7 @@ char *str;
return;
}
- opcode = (r16_opcode_info *) hash_find (opcode_hash_control, name);
+ opcode = (rce_opcode_info *) hash_find (opcode_hash_control, name);
if (opcode == NULL)
{
as_bad ("unknown opcode \"%s\"", name);
@@ -1,4 +1,4 @@
-/* tc-r16.c -- Assemble code for the Experimental R16
+/* tc-rce.c -- Assemble code for the Experimental R16
Copyright (C) 1993 Free Software Foundation.